die () {
  echo >&2 "$@"
  exit 1
}

if [ "x$1" = x-l ]; then
  localFiles=t
  shift
fi

if test -f IDMETA; then
  . ./IDMETA
else
  echo "Warning: no IDMETA file.  Limping along anyway" >&2
fi

#we will keep this to get the project name
DEBCHANGELOG=debian/changelog

if [ "x$NAME" != x ]; then
  echo "Got name $NAME from IDMETA file"
elif test -f $DEBCHANGELOG; then
  NAME=`head -1 $DEBCHANGELOG|sed 's/ .*//g'`
  echo "Warning: assuming name $NAME from $DEBCHANGELOG"
else
  die "No $DEBCHANGELOG and no NAME in IDMETA"
fi

if [ "x$2" != x ]; then
  echo "Overriding name $NAME with $2"
  NAME=$2
fi

if [ "x$VERSION" != x ]; then
  echo "Got version $VERSION from IDMETA file"
else
  FULLVERSION=`head -1 $DEBCHANGELOG|sed 's/.*(//g'|sed 's/).*//g'`
  VERSION=`echo $FULLVERSION|sed 's/-.*//g'`
  echo "Warning: assuming version $VERSION from $DEBCHANGELOG"
fi

if [ "x$1" != x ]; then
  echo "Overriding version $VERSION with $1"
  VERSION=$1
fi

trap 'rm -f tmp.tar' 0

if [ -n "$localFiles" ]; then
    echo "WARNING: using local files rather than git tag" >&2
    echo "This is fine for testing, but should not be used for releases " >&2
    pwd=`pwd`
    dir=`basename "$pwd"`
    cd ..
    cp -a "$dir" $NAME-$VERSION
    rm -rf $NAME-$VERSION/.git
    tar cf "$pwd"/tmp.tar $NAME-$VERSION
    rm -rf $NAME-$VERSION
    cd "$dir"
else
    echo "from git"
    git archive --format=tar --prefix=$NAME-$VERSION/ v${VERSION} > tmp.tar || die "This version is not tagged in Git";
fi

tar xf tmp.tar
rm tmp.tar
for file in debian $OMIT_FROM_DIST; do
  if [ -e "$file" ]; then
    echo "Omitting $file from distribution"
    rm -rf $NAME-$VERSION/$file
  fi
done
tar cfz $NAME-$VERSION.tar.gz $NAME-$VERSION
rm -rf $NAME-$VERSION
